@@ -53,12 +53,18 @@ function commit_archive()
     purge_duplicate_archives $file_to_create || 
         error "Unable to purge duplicates of \$file_to_create"
 
-    # security fixes if BM_REPOSITORY_SECURE is set to true
+    # ownership
+    chown_archive "$file_to_create"
+}
+
+# security fixes if BM_REPOSITORY_SECURE is set to true
+function chown_archive {
+    file="$1"
     if [[ "$BM_REPOSITORY_SECURE" = "true" ]]; then
-        chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $file_to_create || 
-            warning "Unable to change the owner of \"\$file_to_create\"."
-        chmod $BM_ARCHIVE_CHMOD $file_to_create ||
-            warning "Unable to change file permissions of \"\$file_to_create\"."
+        chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $file || 
+            warning "Unable to change the owner of \"\$file\"."
+        chmod $BM_ARCHIVE_CHMOD $file ||
+            warning "Unable to change file permissions of \"\$file\"."
     fi
 }
 
@@ -89,6 +95,8 @@ function clean_exit()
         fi            
     fi
     release_lock
+    bm_dbus_send_progress 100 "Finished"
+    bm_dbus_send_event "shutdown" "70"
     exit 70
 }
 
@@ -115,6 +123,8 @@ function handle_tarball_error()
 
     warning "Unable to create \"\$target\", check \$logfile"
     nb_err=$(($nb_err + 1))
+
+    chown_archive "$target"
 }
 
 function __exec_meta_command()
@@ -155,8 +165,8 @@ function __exec_meta_command()
                 debug "$command > $file_to_create 2> $logfile"
                 tail_logfile "$logfile"
                 if [[ "$BM_ENCRYPTION_METHOD" = "gpg" ]]; then
-                    $command 2>$logfile | $compress_bin -f -q -9 2>$logfile | $gpg -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create.$ext.gpg 2> $logfile
-                    debug "$command | $compress_bin -f -q -9 | $gpg -r \"$BM_ENCRYPTION_RECIPIENT\" -e > $file_to_create.$ext.gpg 2> $logfile"
+                    $command 2>$logfile | $compress_bin -f -q -9 2>$logfile | $gpg $BM__GPG_HOMEDIR -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create.$ext.gpg 2> $logfile
+                    debug "$command | $compress_bin -f -q -9 | $gpg $BM__GPG_HOMEDIR -r \"$BM_ENCRYPTION_RECIPIENT\" -e > $file_to_create.$ext.gpg 2> $logfile"
                     file_to_create="$file_to_create.$ext.gpg"
                 else
                     $command 2> $logfile | $compress_bin -f -q -9 > $file_to_create.$ext 2> $logfile
@@ -181,7 +191,7 @@ function __exec_meta_command()
             debug "$command 1> $file_to_create 2>$logfile"
             tail_logfile "$logfile"
             if [[ "$BM_ENCRYPTION_METHOD" = "gpg" ]]; then
-                $command | $gpg -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create.gpg 2> $logfile
+                $command | $gpg $BM__GPG_HOMEDIR -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create.gpg 2> $logfile
                 file_to_create="$file_to_create.gpg"
             else
                 $command 1> $file_to_create 2>$logfile
@@ -216,6 +226,7 @@ function __create_file_with_meta_command()
     if [[ -n "$BM_RET" ]]; then
         commit_archive "$file_to_create"
     fi
+    chown_archive "$file_to_create"
 }
 
 
@@ -484,7 +495,8 @@ function __get_backup_tarball_remote_command()
 # This function will take care of changing the behaviour of BM
 # regarding the error code given
 # 0 is a success case (remove the logfile and commit the archive).
-# 1 is a warning case (don't remove the logfile but commit the archive).
+# tar/1 is a warning case (file changed; don't remove the logfile but commit the archive).
+# dar/11 is a waring case (file changed; don't remove the logfile but commit the archive).
 # >1 is an error code (don't remove the logile, don't commit the archive).
 function check_error_code()
 {
@@ -496,24 +508,42 @@ function check_error_code()
         error_code=0
     fi
 
-    # looks like a warning, if the file exists, it's a warning,
-    # otherwise it's an error
-    if [[ "$error_code" == "1" ]]; then
-        if [[ -f "$file_to_create" ]]; then
-            warning "The archive command returned 1 but the archive has been created; check \"\$logfile\"."
-            commit_archives "$file_to_create"
-        else
-            handle_tarball_error "$file_to_create" "$logfile"
-        fi
-    # an error code greater than 1 occured : fatal error
-    elif [[ "$error_code" -gt 0 ]]; then
-        handle_tarball_error "$file_to_create" "$logfile"
+    # Error checks can depend on the command/error code returned
+    case "$BM__CURRENT_COMMAND" in 
+        "tar")
+            if [[ "$error_code" == "1" ]]; then
+                warning "Tar reported a file changed during archive creation."
+                commit_archives "$file_to_create"
+            elif [[ "$error_code" -gt 0 ]]; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
+        "dar")
+            if [[ "$error_code" == "11" ]]; then
+                warning "Dar reported a file changed during archive creation."
+                commit_archives "$file_to_create"
+            elif [[ "$error_code" -gt 0 ]]; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
+        *)
+            if [[ "$error_code" -gt 0 ]]; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
+    esac
 
-    # error code of 0, success.
-    else
-        rm -f $logfile
-        commit_archives "$file_to_create"
-    fi
+    # Reset the error code 
+    error_code=0
 }
 
 function __get_backup_tarball_command()
@@ -576,6 +606,7 @@ function build_clear_archive
 
         # lzma archives should be piped manually
         "tar.lz")
+            BM__CURRENT_COMMAND="tar"
             if [[ "$verbosedebug" == "true" ]]; then
                 tail -f $logfile &
             fi
@@ -588,6 +619,7 @@ function build_clear_archive
         
         # dar has a special commandline, that cannot fit the common tar way
         "dar")
+            BM__CURRENT_COMMAND="dar"
             debug "$command $target> $logfile 2>&1"
             tail_logfile "$logfile"
 
@@ -597,12 +629,15 @@ function build_clear_archive
 
         # the common commandline
         *)
+            BM__CURRENT_COMMAND="generic"
             debug "$command $file_to_create \"$target\" > $logfile 2>&1"
             tail_logfile "$logfile"
+            debug "$command $file_to_create \"$target\""
             $command $file_to_create "$target" > $logfile 2>&1 || error_code=$?
             check_error_code "$error_code" "$file_to_create" "$logfile"
         ;;
     esac
+    BM__CURRENT_COMMAND=""
 }
 
 
@@ -624,10 +659,10 @@ function build_encrypted_archive
 
     file_to_create="$file_to_create.gpg"
     
-    debug "$command - \"$target\" 2>>$logfile | $gpg -r \"$BM_ENCRYPTION_RECIPIENT\" -e > $file_to_create 2>> $logfile"
+    debug "$command - \"$target\" 2>>$logfile | $gpg $BM__GPG_HOMEDIR -r \"$BM_ENCRYPTION_RECIPIENT\" -e > $file_to_create 2>> $logfile"
     tail_logfile "$logfile"
 
-    $command - "$target" 2>>$logfile | $gpg -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create 2>> $logfile || error_code=$?
+    $command - "$target" 2>>$logfile | $gpg $BM__GPG_HOMEDIR -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create 2>> $logfile || error_code=$?
     check_error_code "$error_code" "$file_to_create" "$logfile"
 }
 
@@ -720,11 +755,25 @@ function __make_local_tarball_token
     t="$1"
     debug "__make_local_tarball_token ($t)"
 
-    if [[ ! -e "$t" ]] || [[ ! -r "$t" ]]; then
-        # first be sure the target exists
+    # look for the target in the blacklist...
+    is_blacklisted="0"
+    for blacklist_pattern in $BM_TARBALL_BLACKLIST; do
+        if [[ "$t" == "$blacklist_pattern" ]]; then
+            is_blacklisted="1"
+        fi
+    done
+
+
+    # ignore the target if it's blacklisted
+    if [[ "$is_blacklisted" == "1" ]]; then
+        info "Target \"\$t\" is found in blacklist, skipping."
+
+    # be sure the target exists
+    elif [[ ! -e "$t" ]] || [[ ! -r "$t" ]]; then
         warning "Target \"\$t\" does not exist, skipping."
         nb_err=$(($nb_err + 1))
     
+    # Everything's OK, do the job
     else
         # we assume we'll build a master backup (full archive).
         # If we make incremental backup, the $master keyword 
@@ -832,6 +881,8 @@ function backup_method_tarball()
 function backup_method_mysql()
 {
     method="$1"
+    mysql_conffile="$HOME/.backup-manager_my.cnf"
+
     debug "backup_method_mysql ($method)"
 
     info "Using method \"\$method\"."
@@ -845,17 +896,19 @@ function backup_method_mysql()
     fi
     
     # if a MySQL Client conffile exists, the password must be inside
-    if [[ -f "$HOME/.my.cnf" ]]; then
-        info "Using existing MySQL client configuration file: \$HOME/.my.cnf"
+    if [[ -f $mysql_conffile ]]; then
+        info "Using existing MySQL client configuration file: \$mysql_conffile"
+        BM_SHOULD_PURGE_MYCNF="false"
     # we create a default one, just with the password
     else
-        warning "Creating a default MySQL client configuration file: \$HOME/.my.cnf"
-        echo "[client]" > $HOME/.my.cnf 
-        echo "# The following password will be sent to all standard MySQL clients" >> $HOME/.my.cnf 
-        echo "password=\"$BM_MYSQL_ADMINPASS\"" >> $HOME/.my.cnf
-        chmod 600 $HOME/.my.cnf
+        warning "Creating a default MySQL client configuration file: \$mysql_conffile"
+        echo "[client]" > $mysql_conffile
+        echo "# The following password will be sent to all standard MySQL clients" >> $mysql_conffile
+        echo "password=\"$BM_MYSQL_ADMINPASS\"" >> $mysql_conffile
+        chmod 600 $mysql_conffile
+        BM_SHOULD_PURGE_MYCNF="true"
     fi
-    base_command="$mysqldump $opt -u$BM_MYSQL_ADMINLOGIN -h$BM_MYSQL_HOST -P$BM_MYSQL_PORT"
+    base_command="$mysqldump --defaults-extra-file=$mysql_conffile $opt -u$BM_MYSQL_ADMINLOGIN -h$BM_MYSQL_HOST -P$BM_MYSQL_PORT"
     compress="$BM_MYSQL_FILETYPE"   
 
     for database in $BM_MYSQL_DATABASES
@@ -869,6 +922,12 @@ function backup_method_mysql()
         fi
         __create_file_with_meta_command
     done   
+
+    # purge the my.cnf file, if created by Backup Manager
+    if [[ "$BM_SHOULD_PURGE_MYCNF" == "true" ]]; then
+        info "Removing default MySQL client configuration file: \$mysql_conffile"
+        rm -f $mysql_conffile
+    fi
 }
 
 function backup_method_svn()
