@@ -1,4 +1,4 @@
-# Copyright (C) 2005 The Backup Manager Authors
+# Copyright  2005-2006 Alexis Sukrieh
 #
 # See the AUTHORS file for details.
 #
@@ -19,20 +19,21 @@
 
 # This will get a filename a will search its 
 # md5hash in the file given as second arg.
-get_md5sum_from_file()
+function get_md5sum_from_file()
 {
-	filename="$1"
-	md5file="$2"
+    filename="$1"
+    md5file="$2"
+    debug "get_md5sum_from_file ($filename, $md5file)"
 
-    if [ -z "$filename" ] || 
-       [ -z "$md5file" ]; then
+    if [[ -z "$filename" ]] || 
+       [[ -z "$md5file" ]]; then
         error "Internal error: bad usage of function get_md5sum_from_file()"
     fi
 
-	if [ ! -f $md5file ]; then
-		error "No md5file found: \$md5file"
-	fi
-	
+    if [[ ! -f $md5file ]]; then
+        error "No md5file found: \$md5file"
+    fi
+    
     filename="$(basename $filename)"
     md5=$(grep "$filename" $md5file 2>/dev/null | awk '{print $1}') || md5=""
     
@@ -40,20 +41,22 @@ get_md5sum_from_file()
 }
 
 # Just return the md5 hash of a file
-get_md5sum()
+function get_md5sum()
 {
-	file="$1"
-	if [ -f $file ]; then
-		md5=`$md5sum $file 2>/dev/null` || md5=""
-		if [ -z "$md5" ]; then
-			echo "undefined"
-		else
-			md5=$(echo $md5 | awk '{print $1}')
-			echo "$md5"
-		fi
-	else
-		echo "undefined"
-	fi
+    file="$1"
+    debug "get_md5sum ($file)"
+
+    if [[ -f $file ]]; then
+        md5=`$md5sum $file 2>/dev/null` || md5=""
+        if [[ -z "$md5" ]]; then
+            echo "undefined"
+        else
+            md5=$(echo $md5 | awk '{print $1}')
+            echo "$md5"
+        fi
+    else
+        echo "undefined"
+    fi
 }
 
 # Will take an archive path and the path
@@ -63,19 +66,20 @@ get_md5sum()
 # the given archive path in order to get the 
 # MD5 hash from the BM_REPOSITORY_ROOT.
 # 
-save_md5_sum()
+function save_md5_sum()
 {
-	archive="$1"
-	archive=$(basename $archive)
-	archive="$BM_REPOSITORY_ROOT/$archive"
-	md5file="$2"
-	if [ -f $archive ]; then
-		hash=$(get_md5sum $archive)
-		base=$(basename $archive)
-		echo "$hash  $base" >> $md5file
-	else
-		warning "Archive given does not exist in the repository: \$archive"
-	fi
+    archive="$1"
+    debug "save_md5_sum ($archive)"
 
+    archive=$(basename $archive)
+    archive="$BM_REPOSITORY_ROOT/$archive"
+    md5file="$2"
+    if [[ -f $archive ]]; then
+        hash=$(get_md5sum $archive)
+        base=$(basename $archive)
+        echo "$hash  $base" >> $md5file
+    else
+        warning "Archive given does not exist in the repository: \$archive"
+    fi
 }
 
